@@ -1,7 +1,7 @@
 import logging
 from os import path
 
-from erdpy import dependencies, errors, utils
+from erdpy import dependencies, errors, utils, guards
 from erdpy.projects import shared
 from erdpy.projects.project_clang import ProjectClang
 from erdpy.projects.project_cpp import ProjectCpp
@@ -12,7 +12,7 @@ logger = logging.getLogger("projects.core")
 
 
 def load_project(directory):
-    _guard_is_directory(directory)
+    guards.is_directory(directory)
 
     if shared.is_source_clang(directory):
         return ProjectClang(directory)
@@ -32,30 +32,27 @@ def build_project(directory, options):
     logger.info("build_project.directory: %s", directory)
     logger.info("build_project.debug: %s", options['debug'])
 
-    _guard_is_directory(directory)
+    guards.is_directory(directory)
     project = load_project(directory)
     project.build(options)
 
 
-def _guard_is_directory(directory):
-    ok = path.isdir(directory)
-    if not ok:
-        raise errors.BadDirectory(directory)
+def run_tests(args):
+    project = args.project
+    directory = args.directory
+    wildcard = args.wildcard
 
-
-def run_tests(project_directory, wildcard):
-    logger.info("run_tests.project_directory: %s", project_directory)
-    logger.info("run_tests.wildcard: %s", wildcard)
+    logger.info("run_tests.project: %s", project)
 
     dependencies.install_module("arwentools")
 
-    _guard_is_directory(project_directory)
-    project = load_project(project_directory)
-    project.run_tests(wildcard)
+    guards.is_directory(project)
+    project = load_project(project)
+    project.run_tests(directory, wildcard)
 
 
 def get_projects_in_workspace(workspace):
-    _guard_is_directory(workspace)
+    guards.is_directory(workspace)
     subfolders = utils.get_subfolders(workspace)
     projects = []
 
